@@ -22,7 +22,6 @@ from typing import (
     Sequence,
 )
 
-
 # external imports
 from packaging.version import Version
 
@@ -59,7 +58,6 @@ def get_implementation() -> Type[DesktopNotifierBase]:
     :returns: A desktop notification backend suitable for the current platform.
     :raises RuntimeError: when passing ``macos_legacy = True`` on macOS 12.0 and later.
     """
-
     if platform.system() == "Darwin":
 
         from .macos_support import is_bundle, is_signed_bundle, macos_version
@@ -75,7 +73,6 @@ def get_implementation() -> Type[DesktopNotifierBase]:
             return CocoaNotificationCenter
 
         elif has_nsusernotificationcenter and is_bundle():
-
             if has_unusernotificationcenter and not is_signed:
                 logger.warning(
                     "Running outside of a signed Framework or bundle: "
@@ -94,7 +91,6 @@ def get_implementation() -> Type[DesktopNotifierBase]:
 
         else:
             # Use dummy backend.
-
             logger.warning(
                 "Notification Center can only be used "
                 "from a signed Framework or app bundle"
@@ -151,7 +147,6 @@ class DesktopNotifier:
         app_icon: Union[Path, str, None] = PYTHON_ICON_PATH,
         notification_limit: Optional[int] = None,
     ) -> None:
-
         impl_cls = get_implementation()
 
         if isinstance(app_icon, Path):
@@ -170,7 +165,6 @@ class DesktopNotifier:
         Runs the given coroutine and returns the result synchronously. This is used as a
         wrapper to conveniently convert the async API calls to synchronous ones.
         """
-
         if self._loop.is_running():
             future = asyncio.run_coroutine_threadsafe(coro, self._loop)
             res = future.result()
@@ -197,7 +191,6 @@ class DesktopNotifier:
     @app_icon.setter
     def app_icon(self, value: Union[Path, str, None]) -> None:
         """Setter: app_icon"""
-
         if isinstance(value, Path):
             value = value.as_uri()
 
@@ -206,8 +199,8 @@ class DesktopNotifier:
     async def request_authorisation(self) -> bool:
         """
         Requests authorisation to send user notifications. This will be automatically
-        called for you when sending a notification for the first time but it may be
-        useful to call manually to request authorisation in advance.
+        called for you when sending a notification for the first time. It also can be
+        called manually to request authorisation in advance.
 
         On some platforms such as macOS and iOS, a prompt will be shown to the user
         when this method is called for the first time. This method does nothing on
@@ -215,7 +208,6 @@ class DesktopNotifier:
 
         :returns: Whether authorisation has been granted.
         """
-
         with self._lock:
             self._did_request_authorisation = True
             return await self._impl.request_authorisation()
@@ -237,6 +229,7 @@ class DesktopNotifier:
         attachment: Union[Path, str, None] = None,
         sound: bool = False,
         thread: Optional[str] = None,
+        timeout: int = -1,
     ) -> Notification:
         """
         Sends a desktop notification.
@@ -280,6 +273,9 @@ class DesktopNotifier:
             platform's default sound will be used, where available.
         :param thread: An identifier to group related notifications together. This is
             ignored on Linux.
+        :param timeout: The duration (in seconds) for which the notification is shown
+            unless dismissed. Only supported on Linux. Default is ``-1`` which implies
+            OS-specified.
 
         :returns: The scheduled notification instance.
         """
@@ -303,13 +299,17 @@ class DesktopNotifier:
             attachment,
             sound,
             thread,
+            timeout,
         )
 
         with self._lock:
-
+            # Ask for authorisation if not already done. On some platforms, this will
+            # trigger a system dialog to ask the user for permission.
             if not self._did_request_authorisation:
                 await self.request_authorisation()
 
+            # We attempt to send the notification regardless of authorization.
+            # The user may have changed settings in the meantime.
             await self._impl.send(notification)
 
             return notification
@@ -327,13 +327,13 @@ class DesktopNotifier:
         attachment: Union[Path, str, None] = None,
         sound: bool = False,
         thread: Optional[str] = None,
+        timeout: int = -1,
     ) -> Notification:
         """
         Synchronous call of :meth:`send`, for use without an asyncio event loop.
 
         :returns: The scheduled notification instance.
         """
-
         coro = self.send(
             title,
             message,
@@ -346,8 +346,8 @@ class DesktopNotifier:
             attachment,
             sound,
             thread,
+            timeout,
         )
-
         return self._run_coro_sync(coro)
 
     @property
